Imports System.Data
Imports System.Data.SqlClient

Partial Class _Default
    Inherits System.Web.UI.Page

    Protected Sub Page_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Load

        ' Execute code only if the page load not is a post back.
        If Page.IsPostBack = False Then

            ' When this page loads we get the value from the "Cat" parameter in the rewritten url and store this value
            ' in the hidden field "HiddenCategory". The "Cat" value are a string that we will use to select data from
            ' the Content table.

            HiddenCategory.Value = Convert.ToString(Request.QueryString("Cat"))

            ' We select articles from the Content table where the CategoryID matches the value in the hidden field
            ' "HiddenCategory". We use an SqlDataAdapter and a PagedDataSource to split up the selected data in pages 
            ' and binds the data to the "ContentListRepeater" control.

            Try
                Dim ConnString As String = ConfigurationManager.ConnectionStrings("ConnectionString").ToString()
                Dim sql As String = "SELECT * FROM Content WHERE CategoryID = @CategoryID ORDER BY Title ASC"

                ' The Using block is used to call dispose (close) automatically even if there are an exception.

                Using cn As New SqlConnection(ConnString), _
                      sad As New SqlDataAdapter(), _
                      cmd As New SqlCommand(sql, cn)
                    cmd.Parameters.Add("@CategoryID", SqlDbType.VarChar, 60).Value = HiddenCategory.Value

                    ' Open the SqlConnection

                    cn.Open()

                    ' We set the SelectCommand for the SqlDataAdapter

                    sad.SelectCommand = cmd

                    ' We create a DataTable that is named to "dt", the Using block is used to call dispose (close) automatically 
                    ' even if there are an exception.

                    Using dt As New DataTable()

                        ' We fill the DataTable with the selected data

                        sad.Fill(dt)

                        ' We create a PagedDataSource that we call "ObjPds" 
                        Dim objPds As PagedDataSource = New PagedDataSource()

                        ' We set the DataSource for our PagedDataSource to the DataTable "dt"

                        objPds.DataSource = dt.DefaultView

                        ' Indicate that the data should be paged

                        objPds.AllowPaging = True

                        ' Set the pagesize

                        objPds.PageSize = 10

                        ' The current page (curpage) is declared as an integer

                        Dim curpage As Int32

                        ' We set the page number for the current page from the page parameter in the url
                        ' or to 1 if there are no page parameter in the url

                        If Not IsNothing(Request.QueryString("page")) Then
                            curpage = Convert.ToInt32(Request.QueryString("page"))
                        Else
                            curpage = 1
                        End If

                        ' The current page index is equal to the current page minus 1 and we need to know this
                        ' to show the right page to the user.

                        objPds.CurrentPageIndex = curpage - 1

                        ' This code is to set the links for the pages in the repeater and the links are
                        ' made up of pagenumbers. We set one link for each page in a literal control and uses the
                        ' / sign first in the link to make sure that the link starts from the root.

                        Dim NumberOfPages As Integer = objPds.PageCount - 1

                        For i As Integer = 0 To NumberOfPages
                            litPages.Text += " <a href=""" & "/" & HiddenCategory.Value & "/page-" & (i + 1) & "/" & """>" & (i + 1) & "</a>"
                        Next i

                        ' This code binds the data to the repeater control

                        ContentListRepeater.DataSource = objPds
                        ContentListRepeater.DataBind()

                    End Using

                End Using
            Catch ex As Exception
                Response.Write(ex.Message)
            End Try
        End If
    End Sub

    Public Function GenerateURL(ByVal Contentname As Object) As String

        ' Create SEO Friendly URL for each content link in the repeater control, this function is called
        ' in the repeater control when data is binded to the control. We use the / sign in front of the url
        ' to be sure that the url starts from the root.

        Dim strConUrl As String = "/" & HiddenCategory.Value & "/" & Contentname & "/"

        Return strConUrl
    End Function
End Class
