﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
// Import namespaces for MS SQL.
using System.Configuration;
using System.Data;
using System.Data.SqlClient;

public partial class Category : System.Web.UI.Page
{
    protected void Page_Load(object sender, System.EventArgs e)
    {

        // Execute code only if the page load not is a post back.
        if (!Page.IsPostBack)
        {

            // When this page loads we get the value from the "Cat" parameter in the rewritten url and store this value
            // in the hidden field "HiddenCategory". The "Cat" value are a string that we will use to select data from
            // the Content table.
            if (Request.QueryString["Cat"] != null)
                HiddenCategory.Value = Convert.ToString(Request.QueryString["Cat"]);

            // We select articles from the Content table where the CategoryID matches the value in the hidden field
            // "HiddenCategory". We use an SqlDataAdapter and a PagedDataSource to split up the selected data in pages 
            // and binds the data to the "ContentListRepeater" control.

            // Declare variables for a connection string and a SELECT statement.
            string ConnString = ConfigurationManager.ConnectionStrings["ConnectionString"].ToString();
            string sql = "SELECT * FROM Content WHERE CategoryID = @CategoryID ORDER BY Title ASC";

            // Create a SqlConnection. The using block is used to call dispose (close) automatically even if 
            // there are an exception.
            using (SqlConnection cn = new SqlConnection(ConnString))
            {
                // We create a SqlDataAdapter that we call "sad".
                SqlDataAdapter sad = new SqlDataAdapter();

                // We create a SqlCommand that we call "cmd".
                SqlCommand cmd = new SqlCommand(sql, cn);

                // We create a PagedDataSource that we call "ObjPds" 
                PagedDataSource objPds = new PagedDataSource();

                // We create a DataTable that is named to "dt"
                DataTable dt = new DataTable();

                // We add parameters for the WHERE clause in the SELECT statement.
                cmd.Parameters.AddWithValue("@CategoryID", HiddenCategory.Value);

                // The Try/Catch/Finally block is used to handle exceptions.
                try
                {

                    // Open the SqlConnection.
                    cn.Open();

                    // We set the SelectCommand for the SqlDataAdapter.
                    sad.SelectCommand = cmd;

                    // We fill the DataTable with the selected data.
                    sad.Fill(dt);

                    // We set the DataSource for our PagedDataSource to the DataTable "dt".
                    objPds.DataSource = dt.DefaultView;

                    // Indicate that the data should be paged.
                    objPds.AllowPaging = true;

                    // Set the pagesize
                    objPds.PageSize = 10;

                    // The current page (curpage) is declared as an integer
                    Int32 curpage = 1;

                    // We set the page number for the current page from the page parameter in the url
                    // or to 1 if there are no page parameter in the url
                    if (Request.QueryString["page"] != null)
                    {
                        curpage = Convert.ToInt32(Request.QueryString["page"]);
                    }
                    else
                    {
                        curpage = 1;
                    }

                    // The current page index is equal to the current page minus 1 and we need to know this
                    // to show the right page to the user.

                    objPds.CurrentPageIndex = curpage - 1;

                    // This code is to set the links for the pages in the repeater and the links are
                    // made up of pagenumbers. We set one link for each page in a literal control and uses the
                    // / sign first in the link to make sure that the link starts from the root.

                    int NumberOfPages = objPds.PageCount - 1;

                    for (int i = 0; i <= NumberOfPages; i++)
                    {
                        litPages.Text += " <a href=\"" + "/" + HiddenCategory.Value + "/page-" + (i + 1) + "/" + "\">" + (i + 1) + "</a>";
                    }

                    // This code binds the data to the repeater control
                    ContentListRepeater.DataSource = objPds;
                    ContentListRepeater.DataBind();

                }
                catch (Exception ex)
                {
                    Response.Write(ex.Message);
                }
                finally
                {
                    // Dispose of resources to avoid memory leakage.
                    sad.Dispose();
                    cmd.Dispose();
                    dt.Dispose();
                }
            }
        }
    }
    protected string GenerateURL(object Contentname)
    {

        // Create SEO Friendly URL for each content link in the repeater control, this function is called
        // in the repeater control when data is binded to the control. We use the / sign in front of the url
        // to be sure that the url starts from the root.
        string strConUrl = "/" + HiddenCategory.Value + "/" + Contentname + "/";

        return strConUrl;
    }
}